==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/GXModules/Gambio/Widgets/ProductList/TextPhrases/english/productListWidget.lang.inc.php <==
<?php
/*--------------------------------------------------------------------------------------------------
    productWidget.lang.inc.php 2019-08-29
    Gambio GmbH
    http://www.gambio.de
    Copyright (c) 2019 Gambio GmbH
    Released under the GNU General Public License (Version 2)
    [http://www.gnu.org/licenses/gpl-2.0.html]
    --------------------------------------------------------------------------------------------------
 */

$t_language_text_section_content_array = [
    'title'                 => 'Product list',
    'description'           => 'With this widget you can easily add a product slider to your shop.',
    'options.general.title' => 'General',
    
    'options.id.label'       => 'ID',
    'options.id.placeholder' => 'HTML element ID',
    
    'options.class.label'       => 'Class',
    'options.class.placeholder' => 'HTML element class',
    
    'options.product.title' => 'Product',
    
    'options.product.label'       => 'Select Product',
    'options.product.placeholder' => 'Type the ID or the name to search',
    
    'options.category.title' => 'Category',
    
    'options.category.label'       => 'Choose Category',
    'options.category.placeholder' => 'Type the ID or the name to search',
    
    'preview.placeholder' => 'Click on the pencil to add products or to select a category',
    
    'options.presentation.title'          => 'Presentation',
    'options.presentation.label'          => 'Presentation',
    'options.presentation.options.slider' => 'Slider',
    'options.presentation.options.list'   => 'List',
    
    'options.maxProducts.label'       => 'Max. displayed products',
    'options.maxProducts.placeholder' => 'placeholder',
    
    'options.random.label' => 'Show article randomly',

    'options.itemPerRowXs.label' => 'Items per row Mobile',
    'options.itemPerRowSm.label' => 'Items per row Small',
    'options.itemPerRowMd.label' => 'Items per row Medium',
    'options.itemPerRowLg.label' => 'Items per row Large',

    'options.listType.label'               => 'Select an article',
    'options.listType.placeholder'         => 'Select an article',
    'options.listType.options.own.list'    => 'Own list',
    'options.listType.options.category'    => 'Category',
    'options.listType.options.deals'       => 'Deals',
    'options.listType.options.recommended' => 'Recommended',
    'options.listType.options.comingSoon'  => 'Coming soon',
    'options.listType.options.new'         => 'New',
    
    'options.productList.label' => 'Product'
];

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/GXModules/Gambio/Widgets/ProductList/TextPhrases/english/productListWidget.lang.inc.php <==
<?php
/*--------------------------------------------------------------------------------------------------
    productWidget.lang.inc.php 2019-08-29
    Gambio GmbH
    http://www.gambio.de
    Copyright (c) 2019 Gambio GmbH
    Released under the GNU General Public License (Version 2)
    [http://www.gnu.org/licenses/gpl-2.0.html]
    --------------------------------------------------------------------------------------------------
 */

$t_language_text_section_content_array = [
    'title'                 => 'Product list',
    'description'           => 'With this widget you can easily add a product slider to your shop.',
    'options.general.title' => 'General',
    
    'options.id.label'       => 'ID',
    'options.id.placeholder' => 'HTML element ID',
    
    'options.class.label'       => 'Class',
    'options.class.placeholder' => 'HTML element class',
    
    'options.product.title' => 'Product',
    
    'options.product.label'       => 'Select Product',
    'options.product.placeholder' => 'Type the ID or the name to search',
    
    'options.category.title' => 'Category',
    
    'options.category.label'       => 'Choose Category',
    'options.category.placeholder' => 'Type the ID or the name to search',
    
    'preview.placeholder' => 'Click on the pencil to add products or to select a category',
    
    'options.presentation.title'          => 'Presentation',
    'options.presentation.label'          => 'Presentation',
    'options.presentation.options.slider' => 'Slider',
    'options.presentation.options.list'   => 'List',
    
    'options.maxProducts.label'       => 'Max. displayed products',
    'options.maxProducts.placeholder' => 'placeholder',
    
    'options.random.label' => 'Show products randomly',

    'options.itemPerRowXs.label' => 'Products per row Mobile',
    'options.itemPerRowSm.label' => 'Products per row Small',
    'options.itemPerRowMd.label' => 'Products per row Medium',
    'options.itemPerRowLg.label' => 'Products per row Large',

    'options.listType.label'               => 'Select a product',
    'options.listType.placeholder'         => 'Select a product',
    'options.listType.options.own.list'    => 'Own list',
    'options.listType.options.category'    => 'Category',
    'options.listType.options.deals'       => 'Deals',
    'options.listType.options.recommended' => 'Recommended',
    'options.listType.options.comingSoon'  => 'Coming soon',
    'options.listType.options.new'         => 'New',
    
    'options.productList.label' => 'Product'
];
